pub fn set_global_transform(
transform: impl ResponseTransform + Sync + Send + 'static,
)Expand description
Sets the default global transform for errors into responses.
pub fn set_global_transform(
transform: impl ResponseTransform + Sync + Send + 'static,
)Sets the default global transform for errors into responses.